Example of pipeline components
==============================

.. basic_components.py
.. +++++++++++++++++++
.. literalinclude:: ../tutorials/ml-workflows/basic_components.py
   :language: python

.. .. automodule:: basic_components
..    :members:
..    :undoc-members:
..    :show-inheritance:

